@@ -1,5 +1,3 @@
-.is_boolean <- function(x) is.logical(x) && length(x) == 1L && !is.na(x)
-
 stopf <- function(fmt, ..., .use_call = TRUE, .call = sys.call(-1L)) {
     .call <- if (isTRUE(.use_call)) .call[1L] else NULL
     msg <- sprintf(fmt, ...)
@@ -14,26 +12,6 @@ warnf <- function(fmt, ..., .use_call = TRUE, .call = sys.call(-1L)) {
     warning(err)
 }
 
-.assert_scalar_character <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
-    .assert_not_missing(x = x, arg = arg, call = call)
-
-    if (!(is.character(x) && length(x) == 1))
-        stopf("`%s` must be a character vector of length 1.", arg, .call = call)
-
-}
-
-.assert_bool <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
-    .assert_not_missing(x = x, arg = arg, call = call)
-
-    if (!(is.logical(x) && length(x) == 1) || is.na(x))
-        stopf("`%s` must be boolean (TRUE/FALSE).", arg, .call = call)
-}
-
-.assert_not_missing <- function(x, arg, call) {
-    if (missing(x))
-        stopf("argument `%s` is missing, with no default.", arg, .call = call)
-}
-
 .is_scalar_whole <- function(x, tol = .Machine$double.eps^0.5) {
     if (is.integer(x) && length(x) == 1L)
         return(TRUE)
